@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -37,7 +37,7 @@ public:
 private:
     void readConfig();
     void writeConfig();
-    SelectThunderbirdFilterFilesWidget *mSelectFilterFilesWidget;
+    SelectThunderbirdFilterFilesWidget *mSelectFilterFilesWidget = nullptr;
 };
 }
 
