@@ -22,25 +22,22 @@
 
 #include "filteractionwithcommand.h"
 
-namespace MailCommon
-{
-
+namespace MailCommon {
 //=============================================================================
 // FilterActionPipeThrough - use external filter app
 // External message filter: executes a shell command with message
 // on stdin; altered message is expected on stdout.
 //=============================================================================
-class FilterActionPipeThrough: public FilterActionWithCommand
+class FilterActionPipeThrough : public FilterActionWithCommand
 {
     Q_OBJECT
 public:
     explicit FilterActionPipeThrough(QObject *parent = nullptr);
-    ReturnCode process(ItemContext &context, bool applyOnOutbound) const Q_DECL_OVERRIDE;
-    SearchRule::RequiredPart requiredPart() const Q_DECL_OVERRIDE;
+    ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    SearchRule::RequiredPart requiredPart() const override;
     static FilterAction *newAction();
-    QString informationAboutNotValidAction() const Q_DECL_OVERRIDE;
+    QString informationAboutNotValidAction() const override;
 };
-
 }
 
 #endif
