@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2009-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2009-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -51,7 +51,7 @@ public:
     Q_DECLARE_FLAGS(SelectionFolderOptions, SelectionFolderOption)
 
     FolderSelectionDialog(QWidget *parent, FolderSelectionDialog::SelectionFolderOptions options);
-    ~FolderSelectionDialog();
+    ~FolderSelectionDialog() override;
 
     void setSelectionMode(QAbstractItemView::SelectionMode mode);
     QAbstractItemView::SelectionMode selectionMode() const;
